@@ -1,5 +1,5 @@
 #
-# Copyright 2019 Venafi, Inc.
+# Copyright 2022 Venafi, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,20 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
-from __future__ import (absolute_import, division, generators, unicode_literals, print_function, nested_scopes,
-                        with_statement)
-
 import logging as log
 import re
 import time
 
 import requests
 
-from .common import MIME_JSON, CertField, ZoneConfig, Policy, KeyType
+from .common import MIME_JSON
 from .connection_tpp_abstract import AbstractTPPConnection, URLS
 from .errors import (ServerUnexptedBehavior, ClientBadData, AuthenticationError)
-from .http import HTTPStatus
+from .http_status import HTTPStatus
 
 TOKEN_HEADER_NAME = "x-venafi-api-key"  # nosec
 
@@ -39,23 +35,24 @@ class TPPConnection(AbstractTPPConnection):
         :param str url:
         :param dict[str,Any] http_request_kwargs:
         """
+        super().__init__()
         self._base_url = url  # type: str
         self._user = user  # type: str
         self._password = password  # type: str
         self._token = None  # type: tuple
         if http_request_kwargs is None:
-            http_request_kwargs = {"timeout": 180}
-        elif "timeout" not in http_request_kwargs:
-            http_request_kwargs["timeout"] = 180
+            http_request_kwargs = {'timeout': 180}
+        elif 'timeout' not in http_request_kwargs:
+            http_request_kwargs['timeout'] = 180
         self._http_request_kwargs = http_request_kwargs or {}
 
     def __setattr__(self, key, value):
-        if key == "_base_url":
+        if key == '_base_url':
             value = self._normalize_and_verify_base_url(value)
         self.__dict__[key] = value
 
     def __str__(self):
-        return "[TPP] %s" % self._base_url
+        return f"[TPP] {self._base_url}"
 
     def get(self, args):
         """
@@ -82,31 +79,39 @@ class TPPConnection(AbstractTPPConnection):
     def _get(self, url="", params=None):
         if not self._token or self._token[1] < time.time() + 1:
             self.auth()
-            log.debug("Token is %s, timeout is %s" % (self._token[0], self._token[1]))
+            log.debug(f"Token is {self._token[0]}, timeout is {self._token[1]}")
 
-        r = requests.get(self._base_url + url, headers={TOKEN_HEADER_NAME: self._token[0], 'content-type':
-                         MIME_JSON, 'cache-control': 'no-cache'}, params=params, **self._http_request_kwargs)
+        r = requests.get(f"{self._base_url}{url}",
+                         headers={TOKEN_HEADER_NAME: self._token[0],
+                                  'content-type': MIME_JSON,
+                                  'cache-control': 'no-cache'},
+                         params=params,
+                         **self._http_request_kwargs)
         return self.process_server_response(r)
 
     def _post(self, url, data=None):
         if not self._token or self._token[1] < time.time() + 1:
             self.auth()
-            log.debug("Token is %s, timeout is %s" % (self._token[0], self._token[1]))
+            log.debug(f"Token is {self._token[0]}, timeout is {self._token[1]}")
 
         if isinstance(data, dict):
-            r = requests.post(self._base_url + url, headers={TOKEN_HEADER_NAME: self._token[0], 'content-type':
-                              MIME_JSON, "cache-control": "no-cache"}, json=data, **self._http_request_kwargs)
+            r = requests.post(f"{self._base_url}{url}",
+                              headers={TOKEN_HEADER_NAME: self._token[0],
+                                       'content-type': MIME_JSON,
+                                       'cache-control': "no-cache"},
+                              json=data,
+                              **self._http_request_kwargs)
         else:
-            log.error("Unexpected client data type: %s for %s" % (type(data), url))
+            log.error(f"Unexpected client data type: {type(data)} for {url}")
             raise ClientBadData
         return self.process_server_response(r)
 
     @staticmethod
     def _normalize_and_verify_base_url(u):
-        if u.startswith("http://"):
-            u = "https://" + u[7:]
-        elif not u.startswith("https://"):
-            u = "https://" + u
+        if u.startswith('http://'):  # nosec
+            u = f"https://{u[7:]}"
+        elif not u.startswith('https://'):
+            u = f"https://{u}"
         if not u.endswith("/"):
             u += "/"
         if u.endswith(URLS.API_BASE_URL):
@@ -116,9 +121,11 @@ class TPPConnection(AbstractTPPConnection):
         return u
 
     def auth(self):
-        data = {"Username": self._user, "Password": self._password}
-        r = requests.post(self._base_url + URLS.AUTHORIZE, json=data,
-                          headers={'content-type': MIME_JSON, "cache-control": "no-cache"},
+        data = {'Username': self._user, 'Password': self._password}
+        r = requests.post(f"{self._base_url}{URLS.AUTHORIZE}",
+                          json=data,
+                          headers={'content-type': MIME_JSON,
+                                   'cache-control': "no-cache"},
                           **self._http_request_kwargs)
 
         status, user = self.process_server_response(r)
@@ -127,13 +134,13 @@ class TPPConnection(AbstractTPPConnection):
             self._token = user["APIKey"], valid_until
             return user
         else:
-            log.error("Authentication status is not %s but %s. Exiting" % (HTTPStatus.OK, status[0]))
+            log.error(f"Authentication status is not {HTTPStatus.OK} but {status[0]}. Exiting")
             raise AuthenticationError
 
     def _read_config_dn(self, dn, attribute_name):
         status, data = self._post(URLS.CONFIG_READ_DN, {
-            "ObjectDN": dn,
-            "AttributeName": attribute_name,
+            'ObjectDN': dn,
+            'AttributeName': attribute_name,
         })
         if status != HTTPStatus.OK:
             raise ServerUnexptedBehavior("")
