@@ -18,19 +18,18 @@ import logging as log
 import re
 import time
 from datetime import datetime, timedelta
-from pprint import pprint
 
 from cryptography import x509
 from cryptography.hazmat.backends import default_backend
 from cryptography.x509 import SignatureAlgorithmOID as AlgOID
 from six.moves.urllib import parse as url_parse
 
-from .pem import parse_pem
 from .common import CertField, CommonConnection, CertificateRequest, CSR_ORIGIN_LOCAL, CSR_ORIGIN_PROVIDED, \
     CSR_ORIGIN_SERVICE, KeyType, CHAIN_OPTION_LAST, CHAIN_OPTION_FIRST, CHAIN_OPTION_IGNORE, Policy, ZoneConfig
 from .errors import VenafiError, ServerUnexptedBehavior, ClientBadData, RetrieveCertificateTimeoutError, \
     CertificateRequestError, CertificateRenewError
-from .http import HTTPStatus
+from .http_status import HTTPStatus
+from .pem import parse_pem
 from .policy import RPA, SPA
 from .policy.pm_tpp import TPPPolicy, is_service_generated_csr, SetAttrResponse, validate_policy_spec, \
     get_int_value
@@ -79,12 +78,26 @@ class URLS:
 
 
 class AbstractTPPConnection(CommonConnection):
+    def __init__(self):
+        super().__init__()
+
+    ARG_URL = 'url'
+    ARG_PARAMS = 'params'
+    ARG_CHECK_TOKEN = 'check_token'  # nosec
+    ARG_INCLUDE_TOKEN_HEADER = 'include_token_header'  # nosec
+    ARG_DATA = 'data'
+
+    def auth(self):
+        raise NotImplementedError
 
     def request_cert(self, request, zone):
-        request_data = {'PolicyDN': self._normalize_zone(zone),
-                        'ObjectName': request.friendly_name,
-                        'DisableAutomaticRenewal': "true"
-                        }
+        request_data = {
+            'PolicyDN': self._normalize_zone(zone),
+            'ObjectName': request.friendly_name,
+            'DisableAutomaticRenewal': "true"
+        }
+        zone_config = self.read_zone_conf(zone)
+        request.update_from_zone_config(zone_config)
 
         if request.csr_origin == CSR_ORIGIN_LOCAL:
             request.build_csr()
@@ -95,7 +108,7 @@ class AbstractTPPConnection(CommonConnection):
             request_data['Subject'] = request.common_name
             request_data['SubjectAltNames'] = self.wrap_alt_names(request)
         else:
-            log.error("CSR Origin option [%s] is not valid. " % request.csr_origin)
+            log.error(f"CSR Origin option [{request.csr_origin}] is not valid")
             raise ClientBadData
 
         if request.origin:
@@ -143,20 +156,23 @@ class AbstractTPPConnection(CommonConnection):
                 else:
                     request_data['CustomFields'] = [custom_field_json]
 
-
-        status, data = self._post(URLS.CERTIFICATE_REQUESTS, data=request_data)
+        args = {
+            self.ARG_URL: URLS.CERTIFICATE_REQUESTS,
+            self.ARG_DATA: request_data
+        }
+        status, data = self.post(args)
         if status == HTTPStatus.OK:
             request.id = data['CertificateDN']
             request.cert_guid = data['Guid']
-            log.debug("Certificate successfully requested with request id %s." % request.id)
-            log.debug("Certificate successfully requested with GUID %s." % request.cert_guid)
+            log.debug(f"Certificate successfully requested with request id {request.id}")
+            log.debug(f"Certificate successfully requested with GUID {request.cert_guid}")
             return True
 
-        log.error("Request status is not %s. %s." % HTTPStatus.OK, status)
+        log.error(f"Request status is not {HTTPStatus.OK}. {status}")
         raise CertificateRequestError
 
     def retrieve_cert(self, cert_request):
-        log.debug("Getting certificate status for id %s" % cert_request.id)
+        log.debug(f"Getting certificate status for id {cert_request.id}")
 
         retrieve_request = dict(CertificateDN=cert_request.id,
                                 Format="base64",
@@ -178,15 +194,16 @@ class AbstractTPPConnection(CommonConnection):
         elif cert_request.chain_option == CHAIN_OPTION_IGNORE:
             retrieve_request['IncludeChain'] = 'false'
         else:
-            log.error("chain option %s is not valid" % cert_request.chain_option)
+            log.error(f"chain option {cert_request.chain_option} is not valid")
             raise ClientBadData
 
         time_start = time.time()
         while True:
             try:
+                # TODO: Change _post() with post(args)
                 status, data = self._post(URLS.CERTIFICATE_RETRIEVE, data=retrieve_request)
             except VenafiError:
-                log.debug("Certificate with id %s not found." % cert_request.id)
+                log.debug(f"Certificate with id {cert_request.id} not found")
                 status = 0
 
             if status == HTTPStatus.OK:
@@ -201,9 +218,8 @@ class AbstractTPPConnection(CommonConnection):
                 log.debug("Waiting for certificate...")
                 time.sleep(2)
             else:
-                raise RetrieveCertificateTimeoutError(
-                    'Operation timed out at %d seconds while retrieving certificate with id %s'
-                    % (cert_request.timeout, cert_request.id))
+                raise RetrieveCertificateTimeoutError(f"Operation timed out at {cert_request.timeout} seconds while "
+                                                      f"retrieving certificate with id {cert_request.id}")
 
     def renew_cert(self, request, reuse_key=False):
         if not request.id and not request.thumbprint:
@@ -213,7 +229,8 @@ class AbstractTPPConnection(CommonConnection):
             request.id = self.search_by_thumbprint(request.thumbprint)
 
         if reuse_key:
-            log.debug("Trying to renew certificate %s" % request.id)
+            log.debug(f"Trying to renew certificate {request.id}")
+            # TODO: Change _post() with post(args)
             status, data = self._post(URLS.CERTIFICATE_RENEW, data={'CertificateDN': request.id})
             if not data['Success']:
                 raise CertificateRenewError
@@ -286,32 +303,34 @@ class AbstractTPPConnection(CommonConnection):
             request_data['Subject'] = request.common_name
             request_data['SubjectAltNames'] = self.wrap_alt_names(request)
 
+        # TODO: Change _post() with post(args)
         status, data = self._post(URLS.CERTIFICATE_RENEW, data=request_data)
         if status == HTTPStatus.OK:
             if 'CertificateDN' in data:
                 request.id = data['CertificateDN']
-            log.debug("Certificate successfully requested with request id %s." % request.id)
+            log.debug(f"Certificate successfully requested with request id {request.id}")
             return True
 
-        log.error("Request status is not %s. %s." % HTTPStatus.OK, status)
+        log.error(f"Request status is not {HTTPStatus.OK}. {status}")
         raise CertificateRequestError
 
     def revoke_cert(self, request):
         if not (request.id or request.thumbprint):
             raise ClientBadData
         d = {
-            "Disable": request.disable
+            'Disable': request.disable
         }
         if request.reason:
-            d["Reason"] = request.reason
+            d['Reason'] = request.reason
         if request.id:
-            d["CertificateDN"] = request.id
+            d['CertificateDN'] = request.id
         elif request.thumbprint:
-            d["Thumbprint"] = request.thumbprint
+            d['Thumbprint'] = request.thumbprint
         else:
             raise ClientBadData
         if request.comments:
-            d["Comments"] = request.comments
+            d['Comments'] = request.comments
+        # TODO: Change _post() with post(args)
         status, data = self._post(URLS.CERTIFICATE_REVOKE, data=d)
         if status in (HTTPStatus.OK, HTTPStatus.ACCEPTED):
             return data
@@ -321,20 +340,33 @@ class AbstractTPPConnection(CommonConnection):
     def import_cert(self, request):
         raise NotImplementedError
 
+    def read_zone_conf(self, tag):
+        args = {
+            self.ARG_URL: URLS.ZONE_CONFIG,
+            self.ARG_DATA: {
+                'PolicyDN': self._normalize_zone(tag)
+            }
+        }
+        status, data = self.post(args=args)
+        if status != HTTPStatus.OK:
+            raise ServerUnexptedBehavior(f"Server returns {status} status on reading zone configuration")
+        return self._parse_zone_data_to_object(data)
+
     def get_policy(self, zone):
         # get policy spec from name
         policy_name = self._normalize_zone(zone)
         exists = self._policy_exists(policy_name)
         if not exists:
-            log.error('The Policy %s does not exist', policy_name)
+            log.error(f"The Policy {policy_name} does not exist")
             raise VenafiError
 
+        # TODO: Change _post() with post(args)
         status, data = self._post(URLS.ZONE_CONFIG, {"PolicyDN": policy_name})
         if status != HTTPStatus.OK:
-            raise ServerUnexptedBehavior("Server returns %d status on reading policy configuration." % status)
+            raise ServerUnexptedBehavior(f"Server returns {status} status on reading policy configuration")
 
         if not ('Policy' in data):
-            raise VenafiError("Policy structure not found in response data for [%s] policy", policy_name)
+            raise VenafiError(f"Policy structure not found in response data for [{policy_name}] policy")
         p = data['Policy']
         tpp_policy = TPPPolicy()
 
@@ -366,7 +398,7 @@ class AbstractTPPConnection(CommonConnection):
             tpp_policy.management_type = p[RPA.TPP_MANAGEMENT_TYPE][value]
 
         if not ('Subject' in p):
-            raise VenafiError("Subject structure not found in response data for [%s] policy", policy_name)
+            raise VenafiError(f"Subject structure not found in response data for [{policy_name}] policy")
         subject = p['Subject']
 
         # Organization
@@ -395,7 +427,7 @@ class AbstractTPPConnection(CommonConnection):
             tpp_policy.country = CertField(country[value], country[locked])
 
         if not ('KeyPair' in p):
-            raise VenafiError("KeyPair structure not found in response data for [%s] policy", policy_name)
+            raise VenafiError(f"KeyPair structure not found in response data for [{policy_name}] policy")
         kp = p['KeyPair']
 
         # Key Algorithm
@@ -455,24 +487,25 @@ class AbstractTPPConnection(CommonConnection):
         create_policy = False
         policy_exists = self._policy_exists(name)
         if not policy_exists:
-            log.info("Policy [%s] does not exist, validating parent existence", name)
+            log.info(f"Policy [{name}] does not exist, validating parent existence")
             parent_name = self._get_policy_parent(name)
             if self._policy_exists(parent_name) or parent_name == ROOT_PATH:
-                log.info("Parent policy [%s] exists", parent_name)
+                log.info(f"Parent policy [{parent_name}] exists")
                 create_policy = True
             else:
-                raise VenafiError("Parent Policy [%s] does not exist", parent_name)
+                raise VenafiError(f"Parent Policy [{parent_name}] does not exist")
 
         # Create the policy if necessary
         if create_policy:
-            log.info("Creating Policy [%s]", name)
+            log.info(f"Creating Policy [{name}]")
             policy_request_data = {
-                "Class": POLICY_CLASS,
-                "ObjectDN": name
+                'Class': POLICY_CLASS,
+                'ObjectDN': name
             }
+            # TODO: Change _post() with post(args)
             status, resp_data = self._post(URLS.POLICY_CREATE, data=policy_request_data)
             if status != HTTPStatus.OK:
-                raise VenafiError("Failed to create policy [%s]. Status %s" % (name, status))
+                raise VenafiError(f"Failed to create policy [{name}]. Status {status}")
 
         # Set attributes to policy
         if tpp_policy.contact:
@@ -537,7 +570,8 @@ class AbstractTPPConnection(CommonConnection):
         :rtype: bool
         """
         json_request = build_tpp_request(request)
-        log.info("Requesting SSH Certificate with id %s" % request.key_id)
+        log.info(f"Requesting SSH Certificate with id {request.key_id}")
+        # TODO: Change _post() with post(args)
         status, data = self._post(URLS.SSH_CERTIFICATE_REQUEST, json_request)
 
         if status == HTTPStatus.OK:
@@ -548,10 +582,10 @@ class AbstractTPPConnection(CommonConnection):
                 request.guid = cert_req_response.guid
                 return True
             else:
-                raise VenafiError("An error occurred with status %s. Message: %s"
-                                  % (response_object.error_code, response_object.error_msg))
+                raise VenafiError(f"An error occurred with status {response_object.error_code}. "
+                                  f"Message: {response_object.error_msg}")
         else:
-            raise ServerUnexptedBehavior("Server returns %d status on requesting SSH certificate." % status)
+            raise ServerUnexptedBehavior(f"Server returns {status} status on requesting SSH certificate.")
 
     def retrieve_ssh_cert(self, request):
         """
@@ -560,14 +594,15 @@ class AbstractTPPConnection(CommonConnection):
         :rtype: SSHRetrieveResponse
         """
         json_request = build_tpp_retrieve_request(request)
-        log.info("Retrieving SSH Certificate with id %s" % request.pickup_id)
+        log.info(f"Retrieving SSH Certificate with id {request.pickup_id}")
 
         time_start = time.time()
         while True:
             try:
+                # TODO: Change _post() with post(args)
                 status, data = self._post(URLS.SSH_CERTIFICATE_RETRIEVE, json_request)
             except VenafiError:
-                log.debug("SSH Certificate with id %s not found" % request.pickup_id)
+                log.debug(f"SSH Certificate with id {request.pickup_id} not found")
                 status = 0
 
             if status == HTTPStatus.OK:
@@ -575,18 +610,18 @@ class AbstractTPPConnection(CommonConnection):
                 if response_object.success:
                     return SSHRetrieveResponse(data)
                 else:
-                    log.info("Failed to retrieve certificate with following details:\n"
-                             "DN: %s\nGuid: %s\nErrorCode: %s\nErrorMessage:%s"
-                             % (json_request['DN'], json_request['Guid'], response_object.error_code,
-                                response_object.error_msg))
+                    log.info(f"Failed to retrieve certificate with following details:"
+                             f"\nDN: {json_request['DN']}"
+                             f"\nGuid: {json_request['Guid']}"
+                             f"\nErrorCode: {response_object.error_code}"
+                             f"\nErrorMessage: {response_object.error_msg}")
 
             if (time.time() - time_start) < request.timeout:
                 log.debug("Waiting for certificate...")
                 time.sleep(2)
             else:
-                raise RetrieveCertificateTimeoutError(
-                    'Operation timed out at %d seconds while retrieving SSH certificate with id %s'
-                    % (request.timeout, request.pickup_id))
+                raise RetrieveCertificateTimeoutError(f"Operation timed out at {request.timeout} seconds while "
+                                                      f"retrieving SSH certificate with id {request.pickup_id}")
 
     def retrieve_ssh_config(self, ca_request):
         """
@@ -600,9 +635,9 @@ class AbstractTPPConnection(CommonConnection):
             key = 'DN'
             value = ca_request.template
             if not value.startswith(PATH_SEPARATOR):
-                value = "%s%s" % (PATH_SEPARATOR, value)
+                value = f"{PATH_SEPARATOR}{value}"
             if not value.startswith(CA_ROOT_PATH):
-                value = "%s%s" % (CA_ROOT_PATH, value)
+                value = f"{CA_ROOT_PATH}{value}"
         elif ca_request.guid:
             key = 'guid'
             value = ca_request.guid
@@ -610,8 +645,8 @@ class AbstractTPPConnection(CommonConnection):
             raise ClientBadData("CA Guid or CA template must be provided to retrieve SSH config.")
 
         value = url_parse.quote(value)
-        query = "%s=%s" % (key, value)
-        url = "%s?%s" % (URLS.SSH_CA_PUBLIC_KEY, query)
+        query = f"{key}={value}"
+        url = f"{URLS.SSH_CA_PUBLIC_KEY}?{query}"
 
         args = {
             self.ARG_URL: url,
@@ -627,14 +662,8 @@ class AbstractTPPConnection(CommonConnection):
                 ssh_config_response.ca_principals = details.access_control.default_principals
             return ssh_config_response
         else:
-            raise ServerUnexptedBehavior("Server returns %d status on requesting SSH CA Public Key Data for %s = %s."
-                                         % (status, key, value))
-
-    ARG_URL = 'url'
-    ARG_PARAMS = 'params'
-    ARG_CHECK_TOKEN = 'check_token'  # nosec
-    ARG_INCLUDE_TOKEN_HEADER = 'include_token_header'  # nosec
-    ARG_DATA = 'data'
+            raise ServerUnexptedBehavior(f"Server returns {status} status on requesting "
+                                         f"SSH CA Public Key Data for {key} = {value}")
 
     def get(self, args):
         """
@@ -660,18 +689,19 @@ class AbstractTPPConnection(CommonConnection):
         :param str zone:
         :rtype bool:
         """
-        req_data = {"ObjectDN": zone}
+        req_data = {'ObjectDN': zone}
+        # TODO: Change _post() with post(args)
         status, data = self._post(URLS.POLICY_IS_VALID, data=req_data)
 
         if status != HTTPStatus.OK:
-            raise ServerUnexptedBehavior('Could not complete request. Status %s. %s' % (status, pprint(data)))
+            raise ServerUnexptedBehavior(f"Could not complete request. Status {status}. {data}")
 
         if data['Result'] == 1 and data['Object']['TypeName'] == POLICY_CLASS:
             return True
         elif data['Result'] == 400 and 'Error' in data:
             return False
 
-        log.error("Unknown error while executing. Status: %s.Data: %s." % (status, pprint(data)))
+        log.error(f"Unknown error while executing. Status: {status}.Data: {data}.")
         raise VenafiError
 
     def _set_policy_attr(self, zone, attr_name, attr_values, locked):
@@ -690,14 +720,15 @@ class AbstractTPPConnection(CommonConnection):
             'Values': attr_values
         }
 
+        # TODO: Change _post() with post(args)
         status, response = self._post(URLS.POLICY_SET_ATTRIBUTE, data=data)
         if status != HTTPStatus.OK:
-            raise ServerUnexptedBehavior('Got status %s from server', status)
+            raise ServerUnexptedBehavior(f"Got status {status} from server")
 
         response = self._parse_attr_response(response)
 
         if response.error:
-            raise VenafiError('Error while setting attribute [%s] in policy [%s]' % (attr_name, zone))
+            raise VenafiError(f"Error while setting attribute [{attr_name}] in policy [{zone}]")
 
         return status, response
 
@@ -713,34 +744,26 @@ class AbstractTPPConnection(CommonConnection):
             'AttributeName': attr_name,
         }
 
+        # TODO: Change _post() with post(args)
         status, response = self._post(URLS.POLICY_CLEAR_ATTRIBUTE, data=data)
         if status != HTTPStatus.OK:
-            raise ServerUnexptedBehavior('Got status %s from server', status)
+            raise ServerUnexptedBehavior(f"Got status {status} from server")
 
         response = self._parse_attr_response(response)
 
         if response.error:
-            raise VenafiError('Error while setting attribute [%s] in policy [%s]' % (attr_name, zone))
+            raise VenafiError(f"Error while setting attribute [{attr_name}] in policy [{zone}]")
 
         return status, response
 
     def _reset_policy(self, zone):
-        self._reset_policy_attr(zone, SPA.TPP_DOMAIN_SUFFIX_WHITELIST)
-        self._reset_policy_attr(zone, SPA.TPP_PROHIBIT_WILDCARD)
-        self._reset_policy_attr(zone, SPA.TPP_CERT_AUTHORITY)
-        self._reset_policy_attr(zone, SPA.TPP_ORGANIZATION)
-        self._reset_policy_attr(zone, SPA.TPP_ORG_UNIT)
-        self._reset_policy_attr(zone, SPA.TPP_CITY)
-        self._reset_policy_attr(zone, SPA.TPP_STATE)
-        self._reset_policy_attr(zone, SPA.TPP_COUNTRY)
-        self._reset_policy_attr(zone, SPA.TPP_KEY_ALGORITHM)
-        self._reset_policy_attr(zone, SPA.TPP_KEY_BIT_STR)
-        self._reset_policy_attr(zone, SPA.TPP_ELLIPTIC_CURVE)
-        self._reset_policy_attr(zone, SPA.TPP_MANUAL_CSR)
-        self._reset_policy_attr(zone, SPA.TPP_PROHIBITED_SAN_TYPES)
-        self._reset_policy_attr(zone, SPA.TPP_ALLOWED_PRIVATE_KEY_REUSE)
-        self._reset_policy_attr(zone, SPA.TPP_WANT_RENEWAL)
-        self._reset_policy_attr(zone, SPA.TPP_MANAGEMENT_TYPE)
+        atrr_list = [SPA.TPP_DOMAIN_SUFFIX_WHITELIST, SPA.TPP_PROHIBIT_WILDCARD, SPA.TPP_CERT_AUTHORITY,
+                     SPA.TPP_ORGANIZATION, SPA.TPP_ORG_UNIT, SPA.TPP_CITY, SPA.TPP_STATE, SPA.TPP_COUNTRY,
+                     SPA.TPP_KEY_ALGORITHM, SPA.TPP_KEY_BIT_STR, SPA.TPP_ELLIPTIC_CURVE, SPA.TPP_MANUAL_CSR,
+                     SPA.TPP_PROHIBITED_SAN_TYPES, SPA.TPP_ALLOWED_PRIVATE_KEY_REUSE, SPA.TPP_WANT_RENEWAL,
+                     SPA.TPP_MANAGEMENT_TYPE]
+        for attr in atrr_list:
+            self._reset_policy_attr(zone, attr)
 
     @staticmethod
     def _parse_attr_response(response):
@@ -762,17 +785,17 @@ class AbstractTPPConnection(CommonConnection):
             log.error("Zone argument is empty")
             raise ClientBadData
         if not re.match(r"^((\\[^\\<]+)|([^\\<]+))+$", zone):
-            log.error("Bad zone format: %s" % zone)
+            log.error(f"Bad zone format: {zone}")
             raise ClientBadData
 
         if zone.startswith("\\VED\\Policy"):
             return zone
         elif zone.startswith("VED\\Policy"):
-            return "\\" + zone
+            return f"\\{zone}"
         elif zone.startswith("\\"):
-            return "\\VED\\Policy" + zone
+            return f"\\VED\\Policy{zone}"
         else:
-            return "\\VED\\Policy\\" + zone
+            return f"\\VED\\Policy\\{zone}"
 
     @staticmethod
     def _get_policy_parent(zone):
@@ -780,7 +803,7 @@ class AbstractTPPConnection(CommonConnection):
         :param str zone:
         """
         if zone is None:
-            raise ClientBadData('Zone is empty:')
+            raise ClientBadData("Zone is empty")
         index = zone.rindex('\\')
         # Return a substring of zone that starts at 0 and ends at index. Zone here is treated as an slice
         # zone[0:index] returns the same result
@@ -825,6 +848,7 @@ class AbstractTPPConnection(CommonConnection):
         """
         thumbprint = re.sub(r'[^\dabcdefABCDEF]', "", thumbprint)
         thumbprint = thumbprint.upper()
+        # TODO: Change _post() with post(args)
         status, data = self._get(URLS.CERTIFICATE_SEARCH, params={"Thumbprint": thumbprint})
         if status != HTTPStatus.OK:
             raise ServerUnexptedBehavior
@@ -873,6 +897,7 @@ class AbstractTPPConnection(CommonConnection):
             key_type = KeyType(KeyType.ECDSA, data['Policy']['KeyPair']['EllipticCurve']['Value'])
         else:
             key_type = None
+
         z = ZoneConfig(
             organization=CertField(s['Organization']['Value'], locked=s['Organization']['Locked']),
             organizational_unit=CertField(ou, locked=s['OrganizationalUnit']['Locked']),
@@ -884,13 +909,8 @@ class AbstractTPPConnection(CommonConnection):
         )
         return z
 
-    def read_zone_conf(self, tag):
-        status, data = self._post(URLS.ZONE_CONFIG, {'PolicyDN': self._normalize_zone(tag)})
-        if status != HTTPStatus.OK:
-            raise ServerUnexptedBehavior("Server returns %d status on reading zone configuration." % status)
-        return self._parse_zone_data_to_object(data)
-
     def _get_certificate_details(self, cert_guid):
+        # TODO: Change _get() with get(args)
         status, data = self._get(URLS.CERTIFICATE_SEARCH + cert_guid)
         if status != HTTPStatus.OK:
             raise ServerUnexptedBehavior("")
@@ -909,9 +929,9 @@ class AbstractTPPConnection(CommonConnection):
         if ca_request.template:
             value = ca_request.template
             if not value.startswith(PATH_SEPARATOR):
-                value = "%s%s" % (PATH_SEPARATOR, value)
+                value = f"{PATH_SEPARATOR}{value}"
             if not value.startswith(CA_ROOT_PATH):
-                value = "%s%s" % (CA_ROOT_PATH, value)
+                value = f"{CA_ROOT_PATH}{value}"
             json_request['DN'] = value
         elif ca_request.guid:
             json_request['Guid'] = ca_request.guid
@@ -928,7 +948,7 @@ class AbstractTPPConnection(CommonConnection):
             if response_object.success:
                 return SSHTPPCADetails(data)
             else:
-                raise VenafiError("An error occurred with status %s. Message: %s"
-                                  % (response_object.error_code, response_object.error_msg))
+                raise VenafiError(f"An error occurred with status {response_object.error_code}. "
+                                  f"Message: {response_object.error_msg}")
         else:
-            raise ServerUnexptedBehavior("Server returns %d status on requesting SSH CA details." % status)
+            raise ServerUnexptedBehavior(f"Server returns {status} status on requesting SSH CA details")
